Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckError ¶
CheckError check if error is not nil and panic
func GetContextLogger ¶
GetContextLogger get a logger instance contextualized by service name
Types ¶
type Config ¶
type Config struct {
Discover *DiscoverConfig
Mesh *MeshConfig
Streamer *StreamerConfig
}
Config store the application
type DiscoverConfig ¶
type DiscoverConfig struct {
Port int
}
DiscoverConfig peer discovering config
type ServiceBag ¶
ServiceBag various global object injected to services
type StreamerConfig ¶
StreamerConfig streamer config
Click to show internal directories.
Click to hide internal directories.